==> ejc-probuilddiary-api-3.0.0-20220916.063707-4-sources.jar: com/ejianc/business/probuilddiary/person/vo/PersonInformationVO.java <==
package com.ejianc.business.probuilddiary.person.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 个人日志-工程资料归档及会议情况（资料员）
 * 
 * @author generator
 * 
 */
public class PersonInformationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long personId; // 个人日志id
    private Long informMoldId; // 工作类型id
    private String informMoldName; // 工作类型名称
    private String informMoldCode; // 工作类型编码
    private String informationMemo; // 工作描述
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getInformMoldId() {
        return informMoldId;
    }

    public void setInformMoldId(Long informMoldId) {
        this.informMoldId = informMoldId;
    }
    public String getInformMoldName() {
        return informMoldName;
    }

    public void setInformMoldName(String informMoldName) {
        this.informMoldName = informMoldName;
    }
    public String getInformMoldCode() {
        return informMoldCode;
    }

    public void setInformMoldCode(String informMoldCode) {
        this.informMoldCode = informMoldCode;
    }
    public String getInformationMemo() {
        return informationMemo;
    }

    public void setInformationMemo(String informationMemo) {
        this.informationMemo = informationMemo;
    }
    
}

==> ejc-probuilddiary-api-3.0.0-20220919.091701-11-sources.jar: com/ejianc/business/probuilddiary/person/vo/PersonInformationVO.java <==
package com.ejianc.business.probuilddiary.person.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 个人日志-工程资料归档及会议情况（资料员）
 * 
 * @author generator
 * 
 */
public class PersonInformationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long personId; // 个人日志id
    private Long informMoldId; // 工作类型id
    private String informMoldName; // 工作类型名称
    private String informMoldCode; // 工作类型编码
    private String informationMemo; // 工作描述
    private String fileType; // 文件类型
    private String logNumber;//日志 数目

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }
    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getInformMoldId() {
        return informMoldId;
    }
    @ReferDeserialTransfer
    public void setInformMoldId(Long informMoldId) {
        this.informMoldId = informMoldId;
    }
    public String getInformMoldName() {
        return informMoldName;
    }

    public void setInformMoldName(String informMoldName) {
        this.informMoldName = informMoldName;
    }
    public String getInformMoldCode() {
        return informMoldCode;
    }

    public void setInformMoldCode(String informMoldCode) {
        this.informMoldCode = informMoldCode;
    }
    public String getInformationMemo() {
        return informationMemo;
    }

    public void setInformationMemo(String informationMemo) {
        this.informationMemo = informationMemo;
    }
    
}
